from distutils.core import setup

setup(
                name = 'fortest',
                version = '1.6.0',
                py_modules = ['fortest'],
                author = 'xinxin',
                author_email = '251089003@qq.com',
                url = 'http://www.baidu.com',
                description = 'a for test tab complete',
        )
